@@ -69,7 +69,7 @@ public:
     /** Copy constructor, copies all of the branches derivated on it.*/
     Container(const Container& c);
     
-    virtual Container* copy() const;
+    virtual Container* copy() const override;
     
     /** Destructor. Deletes all the references. */
     virtual ~Container() { qDeleteAll(m_params); }
@@ -119,11 +119,11 @@ public:
     /** @return Returns the string associated to the container type. */
     QString tagName() const;
     
-    virtual QVariant accept(AbstractExpressionVisitor*) const;
+    virtual QVariant accept(AbstractExpressionVisitor*) const override;
     
-    virtual bool isZero() const;
+    virtual bool isZero() const override;
     
-    virtual bool matches(const Object* pattern, QMap< QString, const Object* >* found) const;
+    virtual bool matches(const Object* pattern, QMap< QString, const Object* >* found) const override;
     
     const Container* extractType(Container::ContainerType t) const;
     
